<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Strings for component 'competency', language 'id', version '5.0'.
 *
 * @package     competency
 * @category    string
 * @copyright   1999 Martin Dougiamas and contributors
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$string['allchildrenarecomplete'] = 'Semua anak lengkap';
$string['competencies'] = 'Kompetensi';
$string['competenciesarenotenabled'] = 'Kompetensi tidak diaktifkan.';
$string['competenciessettings'] = 'Setelan Kompetensi';
$string['competency'] = 'Kompetensi';
$string['competencyframework'] = 'Kerangka kompetensi';
$string['completeplanstask'] = 'Selesaikan rencana pembelajaran yang jatuh tempo';
$string['coursecompetencyoutcome_complete'] = 'Selesaikan kompetensi';
$string['coursecompetencyoutcome_evidence'] = 'Lampirkan bukti';
$string['coursecompetencyoutcome_none'] = 'Tidak melakukan apapun';
$string['coursecompetencyoutcome_recommend'] = 'Kirim untuk diulas';
$string['coursemodulecompetencyoutcome_complete'] = 'Selesaikan kompetensi';
$string['coursemodulecompetencyoutcome_evidence'] = 'Lampirkan bukti';
$string['coursemodulecompetencyoutcome_none'] = 'Tidak melakukan apapun';
$string['coursemodulecompetencyoutcome_recommend'] = 'Kirim untuk diulas';
$string['deletecompetencyratings'] = 'Peringkat kompetensi';
$string['duplicateditemname'] = '{$a} (salinan)';
$string['enablecompetencies'] = 'Aktifkan kompetensi';
$string['enablecompetencies_desc'] = 'Kompetensi memungkinkan pengguna untuk dinilai sesuai dengan rencana pembelajaran.';
$string['errorcannotchangeapastduedate'] = 'Tanggal jatuh tempo telah berlalu; itu tidak bisa diubah.';
$string['errorcannotsetduedateinthepast'] = 'Tanggal jatuh tempo tidak bisa disetel di waktu lampau.';
$string['errorcannotsetduedatetoosoon'] = 'Tanggal jatuh tempo terlalu cepat.';
$string['errorcompetencyrule'] = 'Aturan kompetensi kursus \'{$a}\' tidak diketahui';
$string['errorcoursecompetencyrule'] = 'Aturan kompetensi kursus \'{$a}\' tidak diketahui';
$string['errorinvalidcourse'] = 'Kursus tidak valid.';
$string['errornocompetency'] = 'Kompetensi {$a} tidak dapat ditemukan';
$string['errorplanstatus'] = 'Status rencana pembelajaran \'{$a}\' tidak diketahui';
$string['errorscalealreadyused'] = 'Skala tidak dapat diubah, karena sedang digunakan.';
$string['errorscaleconfiguration'] = 'Skala perlu dikonfigurasi dengan memilih item bawaan dan mahir.';
$string['errorusercomptencystatus'] = 'Status kompetensi pengguna \'{$a}\' tidak diketahui';
$string['eventcompetencycreated'] = 'Kompetensi dibuat.';
$string['eventcompetencydeleted'] = 'Kompetensi dihapus.';
$string['eventcompetencyframeworkcreated'] = 'Kerangka kompetensi dibuat.';
$string['eventcompetencyframeworkdeleted'] = 'Kerangka kompetensi dihapus.';
$string['eventcompetencyframeworkupdated'] = 'Kerangka kompetensi diperbarui.';
$string['eventcompetencyframeworkviewed'] = 'Melihat kerangka kompetensi.';
$string['eventcompetencyupdated'] = 'Kompetensi diperbarui.';
$string['eventcompetencyviewed'] = 'Melihat kompetensi.';
$string['eventevidencecreated'] = 'Bukti dibuat.';
$string['eventplanapproved'] = 'Rencana pembelajaran disetujui.';
$string['eventplancompleted'] = 'Rencana pembelajaran lengkap.';
$string['eventplancreated'] = 'Rencana pembelajaran dibuat.';
$string['eventplandeleted'] = 'Rencana pembelajaran dihapus.';
$string['eventplanreopened'] = 'Rencana pembelajaran dibuka kembali.';
$string['eventplanreviewrequestcancelled'] = 'Permintaan tinjauan rencana pembelajaran dibatalkan.';
$string['eventplanreviewrequested'] = 'Peninjauan rencana pembelajaran diminta.';
$string['eventplanreviewstarted'] = 'Tinjauan rencana pembelajaran dimulai.';
$string['eventplanreviewstopped'] = 'Tinjauan rencana pembelajaran dihentikan.';
$string['eventplanunapproved'] = 'Rencana pembelajaran tidak disetujui.';
$string['eventplanunlinked'] = 'Rencana pembelajaran tidak tertaut.';
$string['eventplanupdated'] = 'Rencana pembelajaran diperbarui.';
$string['eventplanviewed'] = 'Melihat rencana pembelajaran.';
$string['eventtemplatecreated'] = 'Templat rencana pembelajaran dibuat.';
$string['eventtemplatedeleted'] = 'Templat rencana pembelajaran dihapus.';
$string['eventtemplateupdated'] = 'Templat rencana pembelajaran diperbarui.';
$string['eventtemplateviewed'] = 'Melihat templat rencana pembelajaran.';
$string['eventusercompetencyplanviewed'] = 'Melihat rencana kompetensi pengguna.';
$string['eventusercompetencyrated'] = 'Kompetensi pengguna dinilai.';
$string['eventusercompetencyratedincourse'] = 'Kompetensi pengguna dinilai pada kursus.';
$string['eventusercompetencyratedinplan'] = 'Kompetensi pengguna dinilai pada rencana pembelajaran.';
$string['eventusercompetencyreviewrequestcancelled'] = 'Permintaan tinjauan kompetensi pengguna dibatalkan.';
$string['eventusercompetencyreviewrequested'] = 'Peninjauan kompetensi pengguna diminta.';
$string['eventusercompetencyreviewstarted'] = 'Tinjauan kompetensi pengguna dimulai.';
$string['eventusercompetencyreviewstopped'] = 'Tinjauan kompetensi pengguna dihentikan.';
$string['eventusercompetencyviewed'] = 'Melihat kompetensi pengguna.';
$string['eventusercompetencyviewedincourse'] = 'Kompetensi pengguna dilihat dalam kursus.';
$string['eventusercompetencyviewedinplan'] = 'Kompetensi pengguna dilihat dalam rencana pembelajaran.';
$string['eventuserevidencecreated'] = 'Bukti pembelajaran sebelumnya dibuat.';
$string['eventuserevidencedeleted'] = 'Bukti pembelajaran sebelumnya dihapus.';
$string['eventuserevidenceupdated'] = 'Bukti pembelajaran sebelumnya diperbarui.';
$string['evidence_competencyrule'] = 'Aturan kompetensi terpenuhi.';
$string['evidence_coursecompleted'] = 'Kursus \'{$a}\' selesai.';
$string['evidence_coursemodulecompleted'] = 'Aktivitas \'{$a}\' selesai.';
$string['evidence_courserestored'] = 'Peringkat tersebut dipulihkan bersama dengan kursus \'{$a}\'.';
$string['evidence_evidenceofpriorlearninglinked'] = 'Bukti pembelajaran sebelumnya \'{$a}\' ditautkan.';
$string['evidence_evidenceofpriorlearningunlinked'] = 'Bukti pembelajaran sebelumnya \'{$a}\' tidak tertaut.';
$string['evidence_manualoverride'] = 'Peringkat kompetensi ditetapkan secara manual.';
$string['evidence_manualoverrideincourse'] = 'Peringkat kompetensi secara manual ditetapkan dalam kursus \'{$a}\'.';
$string['evidence_manualoverrideinplan'] = 'Peringkat kompetensi secara manual ditetapkan dalam rencana pembelajaran \'{$a}\'.';
$string['invalidevidencedesc'] = 'Deskripsi bukti tidak valid';
$string['invalidgrade'] = 'Peringkat tidak valid';
$string['invalidplan'] = 'Rencana pembelajaran tidak valid';
$string['invalidtaxonomy'] = 'Taksonomi tidak valid: {$a}';
$string['invalidurl'] = 'URL tidak valid. Pastikan diawali dengan \'http://\' atau \'https://\'.';
$string['nouserplanswithcompetency'] = 'Tidak ada rencana pembelajaran yang mengandung kompetensi ini.';
$string['planstatusactive'] = 'Aktif';
$string['planstatuscomplete'] = 'Selesai';
$string['planstatusdraft'] = 'Draf';
$string['planstatusinreview'] = 'Dalam peninjauan';
$string['planstatuswaitingforreview'] = 'Menunggu peninjauan';
$string['pointsrequiredaremet'] = 'Poin yang dibutuhkan terpenuhi';
$string['privacy:evidence:action:complete'] = 'Lengkapi kompetensi jika tidak dinilai';
$string['privacy:evidence:action:log'] = 'Log aksi';
$string['privacy:evidence:action:override'] = 'Mengesampingkan peringkat kompetensi';
$string['privacy:metadata:competency'] = 'Rekaman kompetensi';
$string['privacy:metadata:competency_coursecomp'] = 'Rekaman kompetensi yang ditautkan ke kursus';
$string['privacy:metadata:competency_coursecompsetting'] = 'Rekaman kompetensi yang disetel ke kursus';
$string['privacy:metadata:competency_evidence'] = 'Rekaman bukti yang memengaruhi status kompetensi';
$string['privacy:metadata:competency_framework'] = 'Rekaman kerangka kompetensi';
$string['privacy:metadata:competency_modulecomp'] = 'Rekaman kompetensi yang ditautkan ke modul';
$string['privacy:metadata:competency_plan'] = 'Rekaman rencana pembelajaran';
$string['privacy:metadata:competency_plancomp'] = 'Rekaman kompetensi dalam rencana pembelajaran';
$string['privacy:metadata:competency_relatedcomp'] = 'Rekaman hubungan antar-kompetensi';
$string['privacy:metadata:competency_template'] = 'Rekaman templat rencana pembelajaran';
$string['privacy:metadata:competency_templatecohort'] = 'Rekaman kohor yang terkait dengan templat rencana pembelajaran';
$string['privacy:metadata:competency_templatecomp'] = 'Rekaman kompetensi dalam templat rencana pembelajaran';
$string['privacy:metadata:competency_usercomp'] = 'Rekaman status kompetensi pengguna';
$string['privacy:metadata:competency_usercompcourse'] = 'Rekaman status kompetensi pengguna dalam kursus';
$string['privacy:metadata:competency_usercompplan'] = 'Rekaman status kompetensi dalam rencana pembelajaran';
$string['privacy:metadata:competency_userevidence'] = 'Rekaman bukti pembelajaran sebelumnya';
$string['privacy:metadata:competency_userevidencecomp'] = 'Rekaman kompetensi yang terkait dengan bukti pembelajaran sebelumnya';
$string['privacy:metadata:core_comments'] = 'Komentar dibuat tentang rencana pembelajaran dan kompetensi';
$string['privacy:metadata:evidence:action'] = 'Jenis tindakan yang diambil dengan bukti';
$string['privacy:metadata:evidence:actionuserid'] = 'Pengguna yang melakukan tindakan';
$string['privacy:metadata:evidence:desca'] = 'Parameter opsional dari deskripsi bukti yang dapat diterjemahkan';
$string['privacy:metadata:evidence:desccomponent'] = 'Komponen deskripsi bukti yang dapat diterjemahkan';
$string['privacy:metadata:evidence:descidentifier'] = 'Pengenal deskripsi bukti yang dapat diterjemahkan';
$string['privacy:metadata:evidence:grade'] = 'Nilai yang terkait dengan bukti';
$string['privacy:metadata:evidence:note'] = 'Catatan non-lokal yang dilampirkan pada bukti';
$string['privacy:metadata:evidence:url'] = 'URL yang terkait dengan bukti';
$string['privacy:metadata:plan:description'] = 'Deskripsi rencana pembelajaran';
$string['privacy:metadata:plan:duedate'] = 'Tanggal jatuh tempo rencana pembelajaran';
$string['privacy:metadata:plan:name'] = 'Nama rencana pembelajaran';
$string['privacy:metadata:plan:reviewerid'] = 'ID peninjau rencana pembelajaran';
$string['privacy:metadata:plan:status'] = 'Status rencana pembelajaran
';
$string['privacy:metadata:plan:userid'] = 'ID pengguna yang memiliki rencana pembelajaran';
$string['privacy:metadata:timecreated'] = 'Waktu saat rekaman dibuat';
$string['privacy:metadata:timemodified'] = 'Waktu saat rekaman diedit';
$string['privacy:metadata:usercomp:grade'] = 'Nilai yang diberikan untuk kompetensi tersebut';
$string['privacy:metadata:usercomp:proficiency'] = 'Apakah kemahiran tercapai
';
$string['privacy:metadata:usercomp:reviewerid'] = 'ID peninjau';
$string['privacy:metadata:usercomp:status'] = 'Status kompetensi';
$string['privacy:metadata:usercomp:userid'] = 'ID pengguna yang memiliki kompetensi';
$string['privacy:metadata:userevidence:description'] = 'Deskripsi bukti';
$string['privacy:metadata:userevidence:name'] = 'Nama bukti pembelajaran sebelumnya';
$string['privacy:metadata:userevidence:url'] = 'URL yang terkait dengan bukti';
$string['privacy:metadata:usermodified'] = 'Pengguna yang membuat atau mengubah rekaman';
$string['privacy:path:plans'] = 'Rencana pembelajaran';
$string['privacy:path:relatedtome'] = 'Terkait dengan saya';
$string['privacy:path:userevidence'] = 'Bukti pembelajaran sebelumnya';
$string['proficient'] = 'Mahir';
$string['pushcourseratingstouserplans'] = 'Dorong peringkat kursus ke rencana pembelajaran individu';
$string['pushcourseratingstouserplans_desc'] = 'Nilai bawaan untuk setelan kursus untuk memperbarui rencana pembelajaran individu ketika kompetensi kursus dinilai.';
$string['rating'] = 'Peringkat';
$string['syncplanscohorts'] = 'Sinkronkan rencana dari kohor templat rencana pembelajaran';
$string['taxonomy_behaviour'] = 'Perilaku';
$string['taxonomy_competency'] = 'Kompetensi';
$string['taxonomy_concept'] = 'Konsep';
$string['taxonomy_domain'] = 'Domain';
$string['taxonomy_indicator'] = 'Indikator';
$string['taxonomy_level'] = 'Tingkat';
$string['taxonomy_outcome'] = 'Capaian';
$string['taxonomy_practice'] = 'Praktik';
$string['taxonomy_proficiency'] = 'Kecakapan';
$string['taxonomy_skill'] = 'Keterampilan';
$string['taxonomy_value'] = 'Nilai';
$string['usercommentedonacompetency'] = '{$a->fullname} mengomentari kompetensi "{$a->competency}":

{$a->comment}

Lihat: {$a->url}';
$string['usercommentedonacompetencyhtml'] = '<p> {$a->fullname} mengomentari kompetensi "{$a->competency}": </p> <div> {$a->comment} </div> <p>
Lihat: <a href="{$a->url}"> {$a->urlname} </a>. </p>';
$string['usercommentedonacompetencysmall'] = '{$a->fullname} mengomentari kompetensi "{$a->competency}".';
$string['usercommentedonacompetencysubject'] = '{$a} mengomentari sebuah kompetensi.';
$string['usercommentedonaplan'] = '{$a->fullname} mengomentari rencana pembelajaran "{$a->plan}":

{$a->comment}

Lihat: {$a->url}';
$string['usercommentedonaplanhtml'] = '<p> {$a->fullname} mengomentari rencana pembelajaran "{$a->plan}": </p> <div> {$a->comment} </div> <p>
Lihat: <a href="{$a->url}"> {$a->urlname} </a>. </p>';
$string['usercommentedonaplansmall'] = '{$a->fullname} mengomentari rencana pembelajaran "{$a->plan}".';
$string['usercommentedonaplansubject'] = '{$a} mengomentari rencana pembelajaran.';
$string['usercompetency'] = 'Kompetensi pengguna';
$string['usercompetencystatus_idle'] = 'diam';
$string['usercompetencystatus_inreview'] = 'Dalam peninjauan';
$string['usercompetencystatus_waitingforreview'] = 'Menunggu peninjauan';
$string['userplans'] = 'Rencana pembelajaran';
